@@ -27,20 +27,20 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "(C) 1999 ImageMagick Studio LLC"
-#define MagickLibVersion  0x710
-#define MagickLibVersionText  "7.1.0"
-#define MagickLibVersionNumber  10,0,0
-#define MagickLibAddendum  "-51"
+#define MagickLibVersion  0x712
+#define MagickLibVersionText  "7.1.2"
+#define MagickLibVersionNumber  10,0,2
+#define MagickLibAddendum  "-4 (Beta)"
 #define MagickLibInterface  10
 #define MagickLibMinInterface  10
 #define MagickPlatform  "x86_64"
-#define MagickppLibVersionText  "7.1.0"
+#define MagickppLibVersionText  "7.1.2"
 #define MagickppLibVersionNumber  5:0:0
-#define MagickppLibAddendum  "-51"
+#define MagickppLibAddendum  "-4 (Beta)"
 #define MagickppLibInterface  5
 #define MagickppLibMinInterface  5
-#define MagickGitRevision  "20499"
-#define MagickReleaseDate  "2022-10-16"
+#define MagickGitRevision  "badaa5c35:20251003"
+#define MagickReleaseDate  "2025-10-03"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
